set -e

. /usr/share/cubbli-conf/lib/funcs.sh


usage() {
	cat <<EOF
Usage: legacy-compat.sh [options]

Deploys legacy files for given compatibility level.

Options:
  -l N - deploy files for level N
  -v   - verbose (CC_VERBOSE=yes)
  -q   - quiet (CC_VERBOSE="")
  -s   - simulate (CC_SIMULATE=yes)
  -h   - this help
EOF
}


while getopts l:shvq t; do
	case $t in
	  l)	level="$OPTARG" ;;
	  s)	CC_SIMULATE=yes ;;
	  v)	CC_VERBOSE=yes ;;
	  q)	CC_VERBOSE="" ;;
	  h)	usage; exit 0 ;;
	  ?)	usage; exit 2 ;;
	esac
done


if ! test "$cc_var"; then
	echo "\$cc_var is unset! Aborting..."
	exit 9
fi

if ! test "$level"; then
	echo "\$level is unset."
	usage
	exit 1
fi

legacy="$cc_share/legacy/$level"

if ! test -d "$legacy"; then
	echo "no legacy files for compatibility level $level"
	exit 1
fi


test "$CC_SIMULATE" && sim="echo simulate: " || sim=

(
	find "$cc_var" -mindepth 1 -maxdepth 1 -type f -name '*.files' -print0 |
			xargs -0 cat;
	cc_get_hashed_files
) | sort -u |
while read file; do
	if cc_check_backup; then
		test ! "$CC_VERBOSE" || echo "$file: already deployed ($RET)"
		continue
	fi

	dir=$(dirname "$file")
	if test -f "$legacy/$file$cc_pf_bak"; then
		if $sim cp -a "$legacy/$file$cc_pf_bak" "$dir"; then
			test ! "$CC_VERBOSE" || echo "$file$cc_pf_bak: deployed"
		else
			echo "$file$cc_pf_bak: failed to deploy" >&2
		fi
	elif test -f "$legacy/$file$cc_pf_del"; then
		if $sim cp -a "$legacy/$file$cc_pf_del" "$dir"; then
			test ! "$CC_VERBOSE" || echo "$file$cc_pf_del: deployed"
		else
			echo "$file$cc_pf_del: failed to deploy" >&2
		fi
	else
		test ! "$CC_VERBOSE" || echo "$file: no such legacy file" >&2
	fi
done
